<!--
title: RadioFreqs.space Guide to SSH Keys
-->

# SSH Keys

## how to make an ssh key

SSH supports a handful of types of cryptographic keys. The most used are [RSA](<https://en.wikipedia.org/wiki/RSA_(cryptosystem)>) and the more modern [Ed25519](https://en.wikipedia.org/wiki/EdDSA#Ed25519).

RSA is the de-facto standard and is supported everywhere (just choose a big enough key like 4096bits to be secure). Ed25519 is designed to be faster and smaller withouth sacrificing security, so is best suited for embedded devices or machines with low resources. It's supported on tilde (and really on anymodern system) but you may find older systems which do not support it.

Below you'll find instructions to generate either type (or both if you want).

Keep in mind that these instructions leave your private keys unencrypted in your local hard disk. So keep them private; never share them.
A good solution is to provide a password for them at creation time, but this implies entering a password any time you used them (impractical) or use something like [ssh-agent](https://man.openbsd.org/ssh-agent.1) (a bit more complex)

We don't have documentation for this [(yet)](https://tildegit.org/team/site/src/branch/master/wiki) so either go with no password keys, or ask on IRC ([#team](https://web.tilde.chat/?join=team)) for help.

pick your fighter: [[mac](#mac)] | [[windows](#windows)] | [[linux](#linux)]

---

### mac

#### generating your keypair

1. open terminal (it's in `/Applications/Utilities`)

1. create your .ssh directory:

```bash
mkdir -m 700 ~/.ssh
```

1. create your keys:

for rsa keys:

```bash
ssh-keygen -t rsa -b 4096
```

for dd25519 keys:

```bash
ssh-keygen -t ed25519 -a 100
```

1. if you press enter to accept the defaults, your public and private key will be located at `~/.ssh/id_rsa.pub` and `~/.ssh/id_rsa` respectively (or `~/.ssh/id_ed25519.pub` and `~/.ssh/id_ed25519` if you chose ed25519 type)

1. `cat ~/.ssh/id_rsa.pub` (or `cat ~/.ssh/id_ed25519.pub` for ed25519)

1. copy the output of the last command and paste it in the sshkey field on the signup form (or email it to [~sudoers](mailto:sudoers@tilde.team) if you already have an account)

#### using your keypair

once [~ben](https://tilde.team/~ben/) or another admin approves your signup, you can join the tilde.team

1. open terminal (it's in `/Applications/Utilities`)

1. `ssh` to tilde.team:

```bash
ssh username@tilde.team
```

where username is your username (~ben would use `ssh ben@tilde.team`)

1. profit???

---

### windows

there are a couple options for using ssh on windows these days. i like to use [git bash](https://git-scm.com).

#### generating your keypair

choose from any of the following options:

- [windows subsystem for linux](https://docs.microsoft.com/en-us/windows/wsl/install-win10)
- [msys2](http://www.msys2.org/)
- [git bash](https://git-scm.com)

1. open your new shell

1. create your .ssh directory

```bash
mkdir .ssh
```

1. create your keypair

for rsa keys:

```bash
ssh-keygen -t rsa -b 4096
```

for ed25519 keys:

```bash
ssh-keygen -t ed25519 -a 100
```

1. if you press enter to accept the defaults, your public and private key will be located at `~/.ssh/id_rsa.pub` and `~/.ssh/id_rsa` respectively (or `~/.ssh/id_ed25519.pub` and `~/.ssh/id_ed25519` if you chose ed25519 type)

1. `cat ~/.ssh/id_rsa.pub` (or `cat ~/.ssh/id_ed25519.pub` for ed25519)

1. copy the output of the last command and paste it in the sshkey field on the signup form (or email it to [~sudoers](mailto:sudoers@tilde.team) if you already have an account)

#### using your keypair

once [~ben](https://tilde.team/~ben/) or another admin approves your signup, you can join the tilde.team

1. open terminal (it's in `/Applications/Utilities`)

1. `ssh` to tilde.team:

```bash
ssh username@tilde.team
```

where username is your username (~ben would use `ssh ben@tilde.team`)

1. profit???

---

### linux

there are a lot of linux distros, but `ssh` and `ssh-keygen` should be available in almost all cases. if they're not, look up how to install ssh for your distro.

#### generating your keypair

1. make sure you have a `~/.ssh` directory

```bash
mkdir -m 700 ~/.ssh
```

1. create your keys

for rsa keys:

```bash
ssh-keygen -t rsa -b 4096
```

for ed25519 keys:

```bash
ssh-keygen -t ed25519 -a 100
```

1. if you press enter to accept the defaults, your public and private key will be located at `~/.ssh/id_rsa.pub` and `~/.ssh/id_rsa` respectively (or `~/.ssh/id_ed25519.pub` and `~/.ssh/id_ed25519` if you chose ed25519 type)

1. `cat ~/.ssh/id_rsa.pub` (or `cat ~/.ssh/id_ed25519.pub` for ed25519)

1. copy the output of the last command and paste it in the sshkey field on the signup form (or email it to [sudoers@tilde.team](mailto:sudoers@tilde.team) if you already have an account)

#### using your keypair

once [~ben](https://tilde.team/~ben/) or another admin approves your signup, you can join the tilde.team

1. open a terminal (this depends on your distro)

1. `ssh` to tilde.team:

```bash
ssh username@tilde.team
```

where username is your username (~ben would use `ssh ben@tilde.team`)

1. profit???

---

this tutorial is taken from [tilde.team ssh wiki page](https://tilde.team/wiki/?page=ssh) uses parts of [the tilde.club ssh primer](https://github.com/tildeclub/tilde.club/blob/master/docs/ssh.md) and [the tilde.town ssh guide](https://tilde.town/wiki/ssh.html).

[back](/)
